package com.gct.centralbase.controller;


import com.gct.centralbase.service.CbPcDevWellAttrService;
import com.gct.common.core.entity.PageRequest;
import com.gct.centralbase.entity.CbPcDevWellAttr;
import com.gct.common.core.result.CodeMsgEnum;
import com.gct.common.core.result.Result;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.method.P;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 开发井基础数据 前端控制器
 * </p>
 *
 * @author wsy
 * @since 2021.8.16
 */
@RestController
@Api(value = "CbPcDevWellAttrController", description = "单井属性接口--添加/修改/删除/分页查询")
@RequestMapping("/cbPcDevWellAttr")
public class CbPcDevWellAttrController {

    @Autowired
    CbPcDevWellAttrService cbPcDevWellAttrService;

    @ApiOperation(value = "selectOneByWellId(根据井号获取单井属性数据)", notes = "单井属性数据")
    @GetMapping("/selectOneByWellId")
    public Result selectOneByWellId(@RequestParam("well_id") @ApiParam("输入井号") String well_id) {
        return cbPcDevWellAttrService.selectOneByWellId(well_id);
    }


    @ApiOperation(value = "addCbPcDevWellAttr(添加单井属性数据)", notes = "添加单井属性数据")
    @PostMapping("/addCbPcDevWellAttr")
    public Result addCbPcDevWellAttr(@RequestBody CbPcDevWellAttr cbPcDevWellAttr){
        return cbPcDevWellAttrService.addCbPcDevWellAttr(cbPcDevWellAttr);
    }

    @ApiOperation(value = "updateCbPcDevWellAttr(修改单井属性数据)", notes = "修改单井属性数据")
    @PostMapping("/updateCbPcDevWellAttr")
    public Result updateCbPcDevWellAttr(@RequestBody CbPcDevWellAttr cbPcDevWellAttr){
        return cbPcDevWellAttrService.updateCbPcDevWellAttr(cbPcDevWellAttr);
    }

    @ApiOperation(value = "deleteCbPcDevWellAttr(删除单井属性数据)", notes = "删除单井属性数据")
    @GetMapping("/deleteCbPcDevWellAttr")
    public Result deleteCbPcDevWellAttr(@RequestParam("well_ids") @ApiParam("输入井号") String well_ids ){
        boolean removeById = cbPcDevWellAttrService.removeById(well_ids);
        System.out.println(removeById);
        return  removeById?Result.create(CodeMsgEnum.DELETE_SUCCESS):Result.create(CodeMsgEnum.DELETE_FAIL);
    }


    @ApiOperation(value = "findAllCbPcDevWellAttr(根据参数查询单井属性数据--分页查询)", notes = "根据参数查询单井属性数据")
    @GetMapping("/findAllCbPcDevWellAttr")
    public Result findAllCbPcDevWellAttr(
            @ApiParam(name = "pageNum",value = "当前页",required = true) @RequestParam("pageNum") Integer pageNum,
            @ApiParam(name = "pageSize",value = "页大小",required = true) @RequestParam("pageSize") Integer pageSize,
            @ApiParam(name = "org_id",value = "组织Id") @RequestParam(value = "org_id",required = false) String org_id,
            @ApiParam(name = "well_id",value = "井号") @RequestParam(value = "well_id",required = false) String well_id,
            @ApiParam(name = "oil_products_sorting",value = "油井分类") @RequestParam(value = "oil_products_sorting",required = false) String oil_products_sorting,
            @ApiParam(name = "test_type",value = "量油方式") @RequestParam(value = "test_type",required = false) String test_type,
            @ApiParam(name = "start_prod_stitum",value = "投产措施") @RequestParam(value = "start_prod_stitum",required = false) String start_prod_stitum,
            @ApiParam(name = "oil_production_method",value = "采油方式") @RequestParam(value = "oil_production_method",required = false) String oil_production_method,
            @ApiParam(name = "injection_method",value = "注入方式") @RequestParam(value = "injection_method",required = false) String injection_method,
            @ApiParam(name = "is_deviated",value = "是否斜井") @RequestParam(value = "is_deviated",required = false) String is_deviated,
            @ApiParam(name = "beginDate",value = "开始时间") @RequestParam(value = "beginDate",required = false) String beginDate,
            @ApiParam(name = "endDate",value = "截止时间") @RequestParam(value = "endDate",required = false) String endDate
    ){
        return cbPcDevWellAttrService.findAllCbPcDevWellAttr(pageNum,pageSize,org_id,well_id,oil_products_sorting,test_type,start_prod_stitum,oil_production_method,injection_method,is_deviated,beginDate,endDate);
    }

}

