package com.gct.centralbase.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.metadata.OrderItem;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.gct.centralbase.entity.CbPcDevWellAttr;
import com.gct.centralbase.mapper.CbPcDevWellAttrMapper;
import com.gct.centralbase.service.CbPcDevWellAttrService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.CodeMsg;
import com.gct.common.core.result.CodeMsgEnum;
import com.gct.common.core.result.Result;
import com.gct.common.security.util.PasswordUtils;
import org.apache.ibatis.annotations.Param;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;

/**
 * <p>
 * 开发单井属性数据 服务实现类
 * </p>
 *
 * @author wsy
 * @since 2021-08-16
 */
@Service
public class CbPcDevWellAttrServiceImpl extends ServiceImpl<CbPcDevWellAttrMapper, CbPcDevWellAttr> implements CbPcDevWellAttrService {

    @Autowired
    CbPcDevWellAttrMapper cbPcDevWellAttrMapper;

    /**
     *根据Id查询单井属性数据
     * @param well_id
     * @return
     */
    @Override
    public Result selectOneByWellId(String well_id){
        CbPcDevWellAttr cbPcDevWellAttr = cbPcDevWellAttrMapper.selectOneByWellId(well_id);
        return Result.ok(cbPcDevWellAttr);
    }


    /**
     * 添加单井属性数据
     * @param cbPcDevWellAttr
     * @return
     * author 王森玉
     * time 2021-8-16
     */
    @Override
    @Transactional
    public Result addCbPcDevWellAttr(CbPcDevWellAttr cbPcDevWellAttr) {
        if(cbPcDevWellAttr.getWellId() != null) {
            if(this.selectOneByWellId(cbPcDevWellAttr.getWellId()).getData() != null) {
                System.out.println(this.selectOneByWellId(cbPcDevWellAttr.getWellId()) );//井信息验证
                return Result.create(CodeMsg.createCodeMsg(-1,"该井信息已存在"));
            }
        }
        //添加单井属性数据
        int insert = cbPcDevWellAttrMapper.insert(cbPcDevWellAttr);
        return insert==1?Result.create(CodeMsgEnum.ADD_SUCCESS):Result.create(CodeMsgEnum.ADD_FAIL);
    }

    /**
     * 修改单井属性信息
     * @param cbPcDevWellAttr
     * @return
     * author 王森玉
     * time 2021-8-16
     */
    public Result updateCbPcDevWellAttr(CbPcDevWellAttr cbPcDevWellAttr)
    {
        int update = cbPcDevWellAttrMapper.updateById(cbPcDevWellAttr);
        System.out.println(update);
        return update==1?Result.create(CodeMsgEnum.MODIFY_SUCCESS):Result.create(CodeMsgEnum.MODIFY_FAIL);
    }

    /**
     * 根据参数条件查询单井属性数据
     * author 王森玉
     * time 2021-8-16
     * @param pageNum
     * @param pageSize
     * @param org_id
     * @param well_id
     * @param oil_products_sorting
     * @param test_type
     * @param start_prod_stitum
     * @param oil_production_method
     * @param injection_method
     * @param is_deviated
     * @param beginDate
     * @param endDate
     * @return
     */
    public Result findAllCbPcDevWellAttr( Integer pageNum, Integer pageSize,String org_id,String well_id,String oil_products_sorting, String test_type, String start_prod_stitum, String oil_production_method, String injection_method, String is_deviated, String beginDate,String endDate)
    {
        String org_id1 ="";
        String well_id1 ="";
        String oil_products_sorting1 ="";
        String test_type1 ="";
        String start_prod_stitum1 ="";
        String oil_production_method1 ="";
        String injection_method1 ="";
        String is_deviated1 ="";

        if (!"".equals(well_id)) {
           well_id1+=well_id;
        }else {
            if (!"%5B0,0,3%5D".equals(org_id))
            {
                org_id1 += org_id;
            }
        }
        if (!"全部".equals(oil_products_sorting) && !"".equals(oil_products_sorting))
        {
            oil_products_sorting1 += oil_products_sorting;
        }
        else
        {
            oil_products_sorting1 +="";
        }
        if (!"全部".equals(test_type) && !"".equals(test_type))
        {
            test_type1 += test_type;
        }
        else
        {
            test_type1 +="";
        }
        if (!"全部".equals(start_prod_stitum) && !"".equals(start_prod_stitum))
        {
            start_prod_stitum1 += start_prod_stitum;
        }
        else
        {
            start_prod_stitum1 +="";
        }
        if (!"全部".equals(oil_production_method) && !"".equals(oil_production_method))
        {
            oil_production_method1 += oil_production_method;
        }
        else {
            oil_production_method1 += "";
        }
        if (!"全部".equals(injection_method) && !"".equals(injection_method))
        {
            injection_method1 += injection_method;
        }
        else
        {
            injection_method1 += "";
        }
        if (!"全部".equals(is_deviated) && !"".equals(is_deviated))
        {
            is_deviated1 += is_deviated;
        }
        else
        {
            is_deviated1 += "";
        }


        Page<CbPcDevWellAttr> paramPage = new Page<>(pageNum, pageSize);
        paramPage.offset();
        paramPage.addOrder(OrderItem.asc("prod_date"));
        IPage<CbPcDevWellAttr> page = cbPcDevWellAttrMapper.selectCbPcDevWellAttrList
                (paramPage, org_id1,well_id1,oil_products_sorting1, test_type1, start_prod_stitum1,oil_production_method1,injection_method1,is_deviated1,beginDate,endDate);
        System.out.println(CbPcDevWellAttr.class);
        return Result.ok(page);
    }

}
