package com.gct.centralbase.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gct.centralbase.entity.CbCdWellSource;
import com.gct.centralbase.entity.CbPcOrganization;
import com.gct.centralbase.mapper.CbPcOrganizationMapper;
import com.gct.centralbase.service.CbCdWellSourceService;
import com.gct.centralbase.service.CbPcOrganizationService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.gct.common.core.result.Result;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 组织机构 服务实现类
 * </p>
 *
 * @author wsy
 * @since 2021-01-19
 */
@Service
public class CbPcOrganizationServiceImpl extends ServiceImpl<CbPcOrganizationMapper, CbPcOrganization> implements CbPcOrganizationService {

    @Autowired
    CbCdWellSourceService cbCdWellSourceService;

    @Override
    public String getParAndSonOrg(JSONArray orgArr) {
        Map<String, JSONObject> tree = new HashMap<>();
        List<CbPcOrganization> orgList = this.list();
        orgList.forEach(x -> {
            tree.put(x.getOrgId(), (JSONObject) JSON.toJSON(x));
        });
        orgList.forEach(x -> {
            JSONObject parent = tree.get(x.getParentId());
            if (parent != null) {
                JSONArray children = parent.getJSONArray("children");
                if (children == null) {
                    children = new JSONArray();
                    parent.put("children", children);
                }
                children.add(tree.get(x.getOrgId()));
            }
        });
        Set<String> res = new HashSet<>();
        orgArr.forEach(node -> {
            res.addAll(findAllSon(tree, (String) node));
            res.addAll(findAllParent(tree,(String) node));
        });
        return JSONObject.toJSONString(res);
    }

    private Set<String> findAllSon(Map<String, JSONObject> tree, String orgId) {
        Set<String> res = new HashSet<>();
        JSONObject node = tree.get(orgId);
        res.add(node.getString("orgId"));
        if (node.getJSONArray("children") != null) {
            node.getJSONArray("children").forEach(obj -> {
                res.addAll(findAllSon(tree, ((JSONObject) obj).getString("orgId")));
            });
        }
        return res;
    }

    private Set<String> findAllParent(Map<String, JSONObject> tree, String orgId) {
        Set<String> res = new HashSet<>();
        while (!orgId.equals("0")) {
            res.add(orgId);
            orgId = tree.get(orgId).getString("parentId");
        }
        return res;
    }

    @Override
    public Result findTree() {
        JSONArray rootArr = new JSONArray();
        Map<String, JSONObject> tree = new HashMap<>();
        List<CbPcOrganization> orgList = this.list();
        orgList.forEach(x -> {
            JSONObject obj = (JSONObject) JSON.toJSON(x);
            if (x.getOrgLevel() == 1) rootArr.add(obj);
            tree.put(x.getOrgId(), obj);
        });
        orgList.forEach(x -> {
            JSONObject parent = tree.get(x.getParentId());
            if (parent != null) {
                JSONArray children = parent.getJSONArray("children");
                if (children == null) {
                    children = new JSONArray();
                    parent.put("children", children);
                }
                children.add(tree.get(x.getOrgId()));
            }
        });
        return Result.ok(rootArr);
    }

    private final String[] columnName = {"org_id", "org_name", "org_level"};
    private final String colParentId = "parent_id";

    @Override
    public Result getOrganization(String orgStr) {

        List<Map<String, Object>> records = null;
//        int currentLevel = 0;
        String defaultItemID = "";
        if (orgStr == null || orgStr.equals("0")) {
            orgStr = "0";//init parent id and set value 0
            records = getOrgChildrenByParent(orgStr);
            defaultItemID = "[0,0,1]";
        } else if (orgStr.contains("[")) {
            /* ps:
             * must to be declared with array parameter, then could select children
             * parent id start with 1 actually,but global default parent id is 0
             * @array parameter: [parent id level(start with 1 and self++),parent id,current level]
             */
            List<Integer> li = JSONObject.parseArray(orgStr, Integer.class);
            Integer parentLevel = li.get(0);
            Integer nextLevel = li.get(2) + 1;
            while (parentLevel < nextLevel) {
                if (records == null)
                    records = getOrgChildrenByParent(li.get(1).toString());
                else {
                    List<Map<String, Object>> nextLevelRecords = new ArrayList<>();
                    for (Map<String, Object> record : records) {
                        List<Map<String, Object>> children = getOrgChildrenByParent(record.get(columnName[0]).toString());
                        nextLevelRecords.addAll(children);
                    }
                    records.clear();
                    records.addAll(nextLevelRecords);
                }
                parentLevel += 1;
            }
            li.set(2, nextLevel);
            defaultItemID = JSONObject.toJSONString(li.toArray());
        } else {
            records = getOrgChildrenByParent(orgStr);
            if (records != null && records.size() > 0) {
                Map<String, Object> re = records.get(0);
                Integer curLevel = (Integer) re.get(columnName[2]);
                defaultItemID = "[" + (curLevel - 1) + "," + orgStr + "," + curLevel + "]";
            }
        }

        if (records != null && records.size() > 1) {
            Map<String, Object> showAllItem = new HashMap<>();
            showAllItem.put(columnName[0], defaultItemID);
            showAllItem.put(columnName[1], "全部");
            records.add(0, showAllItem);
        }
        return Result.ok(records);
    }

    /**
     * simple fun getOrgChildrenByParent
     * Author:  lloyd
     *
     * @param parent_id
     * @return
     */
    private List<Map<String, Object>> getOrgChildrenByParent(String parent_id) {
        QueryWrapper<CbPcOrganization> queryWrapper = new QueryWrapper<>();
        queryWrapper.select(columnName).eq(colParentId, parent_id);
        System.out.println(JSONObject.toJSONString(baseMapper.selectMaps(queryWrapper)));
        return baseMapper.selectMaps(queryWrapper);
    }

    /**
     * 通过id查询该部门下的所有子部门id 列表
     *
     * @param id
     * @return
     */
    @Override
    public List<String> findAllIdById(String id) {
        int org_level = 0;
        if (id == null || id == "0") id = "0";
        else {
            CbPcOrganization orgInput = baseMapper.selectOne(new QueryWrapper<CbPcOrganization>().eq("org_id", id));
            if (orgInput != null) org_level = orgInput.getOrgLevel();
        }
        return findSubOrgIDWithMaxLevel(id, org_level);
    }

    @Override
    public List<CbPcOrganization> getOrgId(String orgId) {
        return baseMapper.getOrgId(orgId);
    }

    @Override
    public CbPcOrganization getOrgById(String id) {
        return baseMapper.selectOne(new QueryWrapper<CbPcOrganization>().eq("org_id", id));
    }


    /**
     * 递归查询所有子部门Id
     *
     * @param id
     * @param list
     */
    private void findIds(String id, List<String> list) {
        list.add(id);
        QueryWrapper<CbPcOrganization> wrapper = new QueryWrapper<>();
        wrapper.eq("parent_id", id);
        List<CbPcOrganization> resources = baseMapper.selectList(wrapper);
        if (resources != null && resources.size() > 0) {
            resources.stream().forEach(CbPcOrganization -> {
                this.findIds(CbPcOrganization.getOrgId(), list);
            });
        }
    }

    @Override
    public Integer getMaxLevelFromOrg() {
        List<Map<String, Object>> one = baseMapper.selectMaps(new QueryWrapper<CbPcOrganization>().select("max(org_level) org_level"));
        if (one == null || one.size() == 0) return null;
        Integer maxLevel = (Integer) one.get(0).get("org_level");
        return maxLevel;
    }

    @Override
    public List<String> findSubOrgIDWithMaxLevel(String id, int level) {

        Integer maxLevel = getMaxLevelFromOrg();
        if (maxLevel == null) return null;
        List<String> ids = new ArrayList<>();
        if (maxLevel == level) {
            ids.add(id);
            return ids;
        }
        String sql = "select org_id from centralbase.cb_pc_organization  where parent_id='" + id + "'";
        for (int i = 0; i < maxLevel - level - 1; i++) {
            sql = "select t" + i + "2.org_id from (" + sql + ") t" + i + " left join centralbase.cb_pc_organization t" + i + "2 on t" + i + ".org_id=t" + i + "2.parent_id";
        }
        System.out.println("sql = " + sql);
        List<CbPcOrganization> res = baseMapper.getSubOrgIDsWithMaxLevel(sql);

        res.forEach((x) -> {
            if (x != null && x.getOrgId() != null && !x.getOrgId().isEmpty())
                ids.add(x.getOrgId());
        });

        return ids;
    }

    @Override
    public String getOrgByWellId(String wellId) {
        CbPcOrganization orgByWellId = baseMapper.getOrgByWellId(wellId);
        String orgIdPre = orgByWellId.getOrgIdPre();
        String[] split = orgIdPre.split("@");
        QueryWrapper<CbPcOrganization> wrapper = new QueryWrapper<CbPcOrganization>().in("org_name",split);
        List<CbPcOrganization> list = baseMapper.selectList(wrapper);
        String orgids ="";
        for (CbPcOrganization cbPcOrganization : list) {
            orgids += cbPcOrganization.getOrgId()  + "@";
        }
        return orgids;
    }

    @Override
    public List<String> getWellIdByOrgId(String orgId) {
        List<String> wellIdLists = new ArrayList<>();
        if (orgId == null || orgId.equals("")) return wellIdLists;
        List<String> threeLevel = isThreeLevel(orgId);
        QueryWrapper<CbCdWellSource> wrapper = new QueryWrapper<CbCdWellSource>()
                .select("well_id")
                .in("org_id",threeLevel);
        List<CbCdWellSource> cbCdWellSources = cbCdWellSourceService.getBaseMapper().selectList(wrapper);
        if (cbCdWellSources !=null && cbCdWellSources.size()>0){
            cbCdWellSources.forEach(x->wellIdLists.add(x.getWellId()));
        }
        wellIdLists.add(orgId);
        return wellIdLists;
    }

    @Override
    public Object getMaxLevelOrgId() {
        QueryWrapper<CbPcOrganization> wrapper = new QueryWrapper<CbPcOrganization>().eq("parent_id",'0').eq("org_level",1);
        return baseMapper.selectList(wrapper);
    }

    public  List<String> isThreeLevel(String orgId){
        QueryWrapper<CbPcOrganization> wrapper = new QueryWrapper<CbPcOrganization>()
                .eq("org_id",orgId);
        CbPcOrganization cbPcOrganization1 = baseMapper.selectById(orgId);
        CbPcOrganization cbPcOrganization = baseMapper.selectOne(wrapper);
        if (cbPcOrganization.getOrgLevel()!=3){
            return  getThreeOrgId(cbPcOrganization.getOrgId());
        }
        return null;
    }

    public List<String> getThreeOrgId(String orgId){
        List<String> wellIdLists = new ArrayList<>();
        QueryWrapper<CbPcOrganization> wrapper = new QueryWrapper<CbPcOrganization>()
                .eq("parent_id",orgId);
        List<CbPcOrganization> list = baseMapper.selectList(wrapper);
        if (list != null && list.size()>0){
            list.forEach(x->{
                if (x.getOrgLevel().equals(3)){
                    wellIdLists.add(x.getOrgId());
                }else {
                    List<String> threeOrgId = getThreeOrgId(x.getOrgId());
                    threeOrgId.forEach(item->wellIdLists.add(item));
                }
            });
        }
        return  wellIdLists;
    }
}
